#!/bin/bash

# script to generate the 3D description file *.acc for TORCS car.

#    file                 : generate.sh
#    created              : 2006-07-22 01:08:22 (UTC+0200)
#    copyleft             : Michel Luc
#    email                : mluc@cern91.net

# ***************************************************************************
# *                                                                         *
# *   This program is free software; you can redistribute it and/or modify  *
# *   it under the terms of the GNU General Public License as published by  *
# *   the Free Software Foundation; either version 2 of the License, or     *
# *   (at your option) any later version.                                   *
# *                                                                         *
# ***************************************************************************


#******************************************************#
# Make sure the directory of binaries used  (accc and
#  stripe) is in your PATH.
#******************************************************#
#
#==================================================
#
# Define TORCS installation directory
BASEDIR="";

# INSTALL in Torcs src directory #
# Don't use that if you have not a Makefile in your Torcs source for this car!
# uncomment to build a new car
#BASEDIR=${TORCS_BASE}/data/cars/models

# INSTALL in Torcs install. directory #
# change it and uncomment if needed!
#BASEDIR=/usr/local/share/games/torcs/cars

# or INSTALL in current directory #
#
#==================================================

# Default car
CAR='fer333';

if [ -z ${BASEDIR} ] || ! -d ${BASEDIR}
	then
		BASEDIR=`pwd`
		WORKDIR=${BASEDIR}
	else
		WORKDIR=${BASEDIR}/${CAR}
fi

if [ ! -d ${WORKDIR} ]
 then
	echo ""
 	echo "ERROR: ${WORKDIR} directory doesnt exist!"
	exit 1
fi

TBINARY=`which accc`
if [ -z ${TBINARY} ]
	then
		echo ""
		echo "ERROR: accc binary not found!"
		echo "Sorry check your PATH."
		echo "Bye!"
		echo ""
		exit 1
fi


#====== start here ======
cd $WORKDIR
clear
echo ""

if [ $# -lt 1 ]
  then 
	echo "Usage: $0 [Car_Name]"
	echo " [ $CAR ] default car used!"
  else
	CAR=$1
fi


if [ ! -r ${CAR}.ac ]
  then
	echo ""
  	echo "WARNING: ${WORKDIR}/$CAR.ac file doesnt exit."
	if [ -e ${CAR}_src.ac ]
  	  then
		cp ${CAR}_src.ac ${CAR}.ac
		echo " ${CAR}_src.ac  used and copyed in ${CAR}.ac"
	else
		echo "ERROR: ${WORKDIR}/${CAR}_src.ac file doesnt exit!"
		exit 1
	fi
fi

echo ""
echo " ======= Cleaning the $CAR.ac file ======"
	echo "*** Crease lines *** (remove all lines with 'Crease value')"
	echo "Press key to continue."
	read KEY1
   	cp $CAR.ac $CAR-bak.ac
   	sed '/crease/d' $CAR.ac > $CAR.ac2 && mv $CAR.ac2 $CAR.ac
	rm $CAR-bak.ac
	echo " All Crease lines removed!"
	echo ""

	echo "*** Mesh lines *** (remove all lines with 'Mesh value')"
	echo "Press key to continue."
	read KEY2
	sed '/Mesh/d' $CAR.ac > $CAR-bak.ac && mv $CAR-bak.ac $CAR.ac
	echo " All Mesh lines removed!"
	echo ""

	echo "Build the $CAR.acc file"
	echo "Press key to continue."
	read KEY3

if [ -e $CAR.acc ]
  then
  	echo "$CAR.acc already exist!"
	echo "Do you want delete $CAR.acc and generate a new one?"
	echo -n "Type 'yes' to delete it, (No/yes)  "
	read FILEDEL
	if [ "$FILEDEL" != "yes" ]
	    then
	        echo "$0 aborted !"
	        exit 1
	    else
	       rm -f $CAR.acc
	fi
fi
	echo "generate $CAR.acc file"
	accc +es 0 $CAR.ac $CAR.acc

echo ""
count=''

if [ -e $CAR-lod1.ac ]
   then
   echo "Do you want to generate the LOD files (No/yes)?"
   read KEY4
   if [ "$KEY4" = "yes" ]
      then
	echo " *** Generate the LOD files ***"
	echo ""
   	echo "generate $CAR-lod1.acc file"
   	accc +es 30 $CAR-lod1.ac $CAR-lod1.acc
	count=1

	if [ -e $CAR-lod2.ac ]
   	   then
      		echo "generate $CAR-lod2.acc file"
      		accc +es 30 $CAR-lod2.ac $CAR-lod2.acc
      		count=2
	fi

	if [ -e $CAR-lod3.ac ]
   	   then
         	echo "generate $CAR-lod3.acc file"
      		accc +es 30 $CAR-lod3.ac $CAR-lod3.acc
      		count=3
	fi

	if [ -e $CAR-lod4.ac ]
   	   then
      		echo "generate $CAR-lod4.acc file"
      		accc +es 30 $CAR-lod4.ac $CAR-lod4.acc
      		count=4
	fi
      fi
fi
if [ -z $count ]
  then
  	echo "No reduce acc files used"
  elif [ ! -e $CAR-lod4.acc ]
    	then
		echo "$CAR-lod4.acc not generated!"
    elif [ ! -e $CAR-lod3.acc ]
         then
                echo "$CAR-lod3.acc not generated!"
    else
  	echo "$count files generated"
  	echo "All done!"
fi

echo ""
exit 0

